OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Vizibil doar pentru persoanele care se potrivesc prin integrarea numărului de telefon prin Talk pe mobil",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Vizibil doar pentru persoanele din această instanță și pentru oaspeți",
    "Federated" : "Federat",
    "Only synchronize to trusted servers" : "Sincronizează doar cu serverele de încredere",
    "Published" : "Publicat",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizarea cu serverele de încredere și cu cartea de adrese globală și publică",
    "Verify" : "Verifică",
    "Verifying …" : "Se verifică ...",
    "Unable to change password" : "Imposibil de schimbat parola",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Groups" : "Grupuri",
    "Group list is empty" : "Lista de grupuri este goală",
    "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
    "{actor} added you to group {group}" : "{actor} te-a adăugat în grupul {group}",
    "You added {user} to group {group}" : "Ai adăugat {user} în grupul {group}",
    "{actor} added {user} to group {group}" : "{actor} a adăugat pe {user} în grupul {group}",
    "An administrator added you to group {group}" : "Un administrator te-a adăugat în grupul {group}",
    "An administrator added {user} to group {group}" : "Un administrator a adăugat pe {user} în grupul {group} ",
    "{actor} removed you from group {group}" : "{actor} te-a eliminat din grupul {group}",
    "You removed {user} from group {group}" : "Ai eliminat {user} din grupul {group}",
    "{actor} removed {user} from group {group}" : "{actor} a eliminat {user} din grupul {group}",
    "An administrator removed you from group {group}" : "Un administrator te-a eliminat din grupul {group}",
    "An administrator removed {user} from group {group}" : "Un administrator a eliminat {user} din groupul {group}",
    "Your <strong>group memberships</strong> were modified" : "<strong>Apartenențele de grup</strong>ale dvs. au fost modificate",
    "{actor} changed your password" : "{actor} ți-a schimbat parola",
    "You changed your password" : "Ți-ai schimbat parola",
    "Your password was reset by an administrator" : "Parola dumneavoastră a fost resetată de un administrator",
    "Your password was reset" : "Parola dvs. a fost resetată",
    "{actor} changed your email address" : "{actor} ți-a schimbat adresa de email",
    "You changed your email address" : "Ți-ai schimbat adresa de email",
    "Your email address was changed by an administrator" : "Adresa ta de email a fost modificată de un administrator",
    "You deleted app password \"{token}\"" : "Ai șters parola aplicației \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Ai redenumit parola aplicației \"{token}\" în \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Ați acordat acces la sistemul de fișiere pentru parola aplicației \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Ați revocat accesul la sistemul de fișiere din aplicația parola \"{token}\"",
    "Security" : "Securitate",
    "You successfully logged in using two-factor authentication (%1$s)" : "Te-ai conectat cu succes utilizând autentificarea cu doi factori (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "O încercare de autentificare utilizând autentificarea cu doi factori a eșuat (%1$s)",
    "Remote wipe was started on %1$s" : "Ștergerea de la distanță a fost pornită pe %1$s",
    "Remote wipe has finished on %1$s" : "Ștergerea de la distanță s-a încheiat pe %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Parola </strong> sau <strong>mailul </strong>a fost modificat",
    "Settings" : "Setări",
    "Wrong password" : "Parolă greșită",
    "Unable to change personal password" : "Nu se poate schimba parola personală",
    "Saved" : "Salvat",
    "Authentication error" : "Eroare la autentificare",
    "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
    "Administrator documentation" : "Documentație pentru administrare",
    "User documentation" : "Documentație utilizator",
    "Invalid SMTP password." : "Parolă SMTP invalidă.",
    "Email setting test" : "Test setări email",
    "Well done, %s!" : "Felicitări, %s!",
    "If you received this email, the email configuration seems to be correct." : "Daca primești acest mail, configurările de email au fost efectuate corect.",
    "Email could not be sent. Check your mail server log" : "Mesajul nu a putut fi trimis. Verifică logul serverului de mail.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
    "Invalid mail address" : "Adresa mail invalidă",
    "Settings saved" : "Setările au fost salvate",
    "Unable to change full name" : "Nu s-a putut schimba numele complet",
    "Unable to change email address" : "Nu s-a putut schimba adresa email",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Pentru a putea verifica contul de Twitter, postați următorul tweet (asigurați-vă că îl postați fără spații):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Pentru a verifica site-ul dvs., stocați următorul conținut în root-ul siteului web la \".well-known / CloudIdVerificationCode.txt\" (asigurați-vă că textul complet este compus dintr-o singură linie):",
    "%1$s changed your password on %2$s." : "%1$s ți-a schimbat parola pe %2$s.",
    "Your password on %s was changed." : "Parola ta pe %s a fost modificată.",
    "Your password on %s was reset by an administrator." : "Parola ta pe %s a fost resetată de către un administrator.",
    "Password for %1$s changed on %2$s" : "Parola pentru %1$s modificată pe %2$s",
    "Password changed for %s" : "Parolă modificată pentru %s",
    "If you did not request this, please contact an administrator." : "Dacă nu ai solicitat aceasta, te rugăm să contactezi un administrator.",
    "Your email address on %s was changed." : "Adresa de mail pe %s a fost modificată.",
    "Your email address on %s was changed by an administrator." : "Adresa de mail pe %s a fost modificată de către un administrator.",
    "Email address for %1$s changed on %2$s" : "Adresa de mail pentru %1$s a fost modificată pe %2$s",
    "Email address changed for %s" : "Adresa de email schimbată în %s",
    "The new email address is %s" : "Adresa de email nouă este%s",
    "Your %s account was created" : "Contul tău %s a fost creat",
    "Welcome aboard" : "Bun venit la bord",
    "Welcome aboard %s" : "Bun venit la bord %s",
    "Set your password" : "Setează parola",
    "Go to %s" : "Salt la %s",
    "Install Client" : "Instalează client",
    "Apps" : "Aplicații",
    "Personal" : "Personal",
    "Administration" : "Administrare",
    "Users" : "Utilizatori",
    "Additional settings" : "Setări adiționale",
    "Administration privileges" : "Privilegii de administrare",
    "Groupware" : "Articole de grup",
    "Overview" : "Prezentare generală",
    "Basic settings" : "Setări de bază",
    "Sharing" : "Partajare",
    "Calendar" : "Calendar",
    "Personal info" : "Informații personale",
    "Mobile & desktop" : "Mobil și desktop",
    "Email server" : "Server de email",
    "Security & setup warnings" : "Alerte de securitate & configurare",
    "Background jobs" : "Proces de fundal",
    "Unlimited" : "Nelimitată",
    "Verifying" : "Se verifică",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Lipsesc coloane opționale din baza de date. Datorită faptului că adăugarea de coloane tabelelor mari durează mult, acestea nu au fost adăugate automat atunci când pot fi opționale. Rulând \"occ db:add-missing-columns\", aceste coloane lipsă pot fi adăugate manual în timp ce instanța este online. Odată ce aceste coloane opționale au fost adăugate, unele funcționalități pot îmbunătăți timpul de răspuns sau uzabilitatea. ",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Lipsesc indecși din baza de date. Datorită faptului că adăugarea indecșilor la tabelele mari durează mult, aceștia nu au fost adăugați automat. Rulând \"occ db:add-missing-indices\", indecși lipsă pot fi adăugați manual în timp ce instanța rulează în continuare. Odată ce indecșii au fost adăugați, interogările acelor tabele vor fi de obicei mai rapide.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Bazei de date îi lipsesc câteva chei primare. Datorită faptului că adăugarea cheilor primare la tabelele mari durează mult, acestea nu au fost adăugate automat. Rulând \"occ db:add-missing-primary-keys\", aceste chei primare lipsă pot fi adăugate manual în timp ce instanța rulează. ",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Instanța este în modul debug. Folosiți aceasta doar pentru dezvoltare și nu în producție.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Acest server nu are o conexiune funcțională la Internet. Mai multe puncte finale nu pot fi contactate. Aceasta înseamnă că unele funcționalități precum montarea unui spațiu extern de stocare, notificări despre actualizări sau instalarea aplicațiilor din sursă terță nu vor fi accesibile. De asemenea, ar putea să nu funcționeze nici accesarea fișierelor la distanță și transmiterea emailurilor de notificare .",
    "Disabled" : "Dezactivați",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Este activat vechiul format de criptare din partea serverului. Vă recomandăm să dezactivați acest lucru.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funcția PHP \"set_time_limit\" nu este disponibilă. Aceasta ar putea avea ca efect ca scripturile să fie oprite în timpul execuției, compromițând instalarea. Se recomandă puternic activarea acestei funcții.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Instalarea PHP nu are suport pentru FreeType, introducând incompatibilități cu imaginile de profil și cu interfața de configurare.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nu pare să fie configurat corespunzător pentru a interoga variabilele de mediu ale sistemului. Testul cu getenv(\"PATH\") returnează doar un răspuns gol.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modulul PHP OPcache nu este încărcat. Pentru o performanță mai bună, se recomandă să îl încărcați în instalarea PHP.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A fost activată configurația doar pentru citire. Acest lucru împiedică setarea unor configurații prin intermediul interfeței web. În plus, fișierul trebuie să fie făcut scriere manual la fiecare actualizare.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza dumneavoastră de date nu rulează cu nivelul de izolare a tranzacției \"READ COMMITTED\". Acest lucru poate cauza probleme atunci când mai multe acțiuni sunt executate în paralel.",
    "Profile information" : "Informații de profil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Poza de profil, numele complet, adresa de e-mail, numărul de telefon, adresa, site-ul web, Twitter, organizația, rolul, titlul, biografia și dacă profilul dvs. este activat.",
    "Nextcloud settings" : "Setări Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Aici puteți decide ce grup poate accesa anumite secțiuni din setările de administrare.",
    "None" : "Niciuna",
    "Unable to modify setting" : "Nu se poate modifica setarea",
    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
    "Allow resharing" : "Permite repartajarea",
    "Allow sharing with groups" : "Permite partajarea cu grupuri",
    "Allow public uploads" : "Permite încărcări publice",
    "Enforce password protection" : "Impune protecția prin parolă",
    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
    "These groups will still be able to receive shares, but not to initiate them." : "Aceste grupuri vor putea în continuare să primească partajări, dar nu să le inițieze.",
    "Enforce expiration date" : "Impune data de expirare",
    "Two-Factor Authentication" : " Autentificare în doi pași",
    "Enforce two-factor authentication" : "Forțează autentificarea cu doi factori",
    "Limit to groups" : "Limitează pentru grupuri",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Forțarea autentificării cu doi factori poate fi setată doar pentru anumite grupuri.",
    "Two-factor authentication is enforced for all members of the following groups." : "Autentificarea cu doi factori este impusă pentru toți membrii următoarelor grupuri.",
    "Enforced groups" : "Grupuri obligate",
    "Two-factor authentication is not enforced for members of the following groups." : "Autentificarea cu doi factori nu este impusă pentru membrii următoarelor grupuri.",
    "Excluded groups" : "Grupuri excluse",
    "Save changes" : "Salvează modificările",
    "All" : "Toate ",
    "No results" : "Niciun rezultat",
    "Update to {version}" : "Actualizare la {version}",
    "Remove" : "Șterge",
    "Disable" : "Dezactivați",
    "View in store" : "Vezi în magazin",
    "Visit website" : "Viziteaza pagina web",
    "Report a bug" : "Raportează un defect",
    "Admin documentation" : "Documentație pentru administrare",
    "Developer documentation" : "Documentație pentru dezvoltatori",
    "Featured" : "Recomandată",
    "Icon" : "Pictogramă",
    "Name" : "Nume",
    "Version" : "Versiunea",
    "Level" : "Nivel",
    "Actions" : "Acțiuni",
    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
    "Device settings" : "Setările dispozitivului",
    "Allow filesystem access" : "Permite accesul la fișierele de sistem",
    "Rename" : "Redenumește",
    "Revoke" : "Revocă",
    "Google Chrome for Android" : "Google Chrome for Android",
    "This session" : "Această sesiune",
    "Device" : "Dispozitiv",
    "Last activity" : "Ultima activitate",
    "Devices & sessions" : "Dispozitive și sesiuni",
    "Web, desktop and mobile clients currently logged in to your account." : "Clienții web, desktop și mobil conectați în prezent la contul dvs.",
    "App name" : "Numele aplicației",
    "Create new app password" : "Crează o nouă parolă pentru aplicație",
    "Error while creating device token" : "Eroare la crearea token-ului de dispozitiv",
    "Login" : "Autentificare",
    "Password" : "Parolă",
    "Enable" : "Activare",
    "Server-side encryption" : "Criptare la nivel de server",
    "Enable server-side encryption" : "Activează criptarea pe server",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Criptarea, ca unică variantă, nu garantează securitatea sistemului. Consultați documentația pentru mai multe informații despre cum funcționează aplicația de criptare și variantele de utilizare acceptate.",
    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
    "Cancel" : "Anulare",
    "Confirm" : "Confirmă",
    "Submit" : "Trimite",
    "Remove group" : "Înlătură grupul",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "Change password" : "Schimbă parola",
    "Details" : "Detalii",
    "Back" : "Înapoi",
    "No email address set" : "Fără adresă de email setată",
    "Help translate" : "Ajută la traducere",
    "Your phone number" : "Numărul tău de telefon",
    "Add" : "Adaugă",
    "Create" : "Creează",
    "Change" : "Schimbă",
    "Delete" : "Șterge",
    "Reshare" : "Redistribuiți",
    "Default language" : "Limba implicită",
    "Display name" : "Nume afișat",
    "Email" : "Email",
    "Quota" : "Cotă",
    "Language" : "Limba",
    "Total rows summary" : "Rezumat total rânduri",
    "Avatar" : "Avatar",
    "Username" : "Nume utilizator",
    "Last login" : "Ultima autentificare",
    "{size} used" : "{size} folosită",
    "Done" : "Realizat",
    "Edit" : "Editează",
    "Visibility" : "Vizibil",
    "Show last login" : "Arată ultima autentificare",
    "Send email" : "Expediază mesajul",
    "Add WebAuthn device" : "Adăugați dispozitivul WebAuthn",
    "Name your device" : "Numiți dispozitivul dvs.",
    "Adding your device …" : "Adăugarea dispozitivului dvs ...",
    "Server error while trying to complete WebAuthn device registration" : "Eroare de server în timpul încercării de a finaliza înregistrarea dispozitivului WebAuthn",
    "Unnamed device" : "Dispozitiv fără nume",
    "Your browser does not support WebAuthn." : "Browserul dvs. nu acceptă WebAuthn.",
    "Changelog" : "Listă modificări",
    "Admins" : "Administratori",
    "Group name" : "Numele grupului",
    "Sending…" : "Se trimite...",
    "Email sent" : "Mesajul a fost expediat",
    "Location" : "Locație",
    "Profile picture" : "Imagine de profil",
    "About" : "Despre",
    "Full name" : "Nume complet",
    "Headline" : "Titlu",
    "Organisation" : "Organizație",
    "Phone number" : "Număr telefon",
    "Role" : "Rol",
    "Website" : "Site web",
    "Your apps" : "Aplicațiile tale",
    "Disabled apps" : "Aplicații inactive",
    "Updates" : "Actualizări",
    "Featured apps" : "Aplicații recomandate",
    "Hide" : "Ascunde",
    "Never" : "Niciodată",
    "Do you really want to wipe your data from this device?" : "Chiar doriți să vă ștergeți datele de pe acest dispozitiv?",
    "Confirm wipe" : "Confirmați ștergerea",
    "Error while wiping the device with the token" : "Eroare la ștergerea dispozitivului cu token-ul",
    "Error while updating device token name" : "Eroare la actualizarea numelui token-ului dispozitivului",
    "Error while updating device token scope" : "Eroare la actualizarea domeniului de aplicare a token-ului de dispozitiv",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Prea multe cereri din această rețea. Încercați mai târziu sau contactați administratorul.",
    "Documentation" : "Documentație",
    "Forum" : "Forum",
    "SSL" : "SSL",
    "Open documentation" : "Deschide documentația",
    "Send mode" : "Modul de expediere",
    "Encryption" : "Încriptare",
    "From address" : "De la adresa",
    "Server address" : "Adresa server-ului",
    "Port" : "Portul",
    "Authentication" : "Autentificare",
    "Authentication required" : "Autentificare necesară",
    "Credentials" : "Detalii de autentificare",
    "SMTP Password" : "Parolă SMTP",
    "Save" : "Salvează",
    "All checks passed." : "Toate verificările s-au terminat fără erori.",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Această versiune comunitară a Nextcloud nu este suportată, iar notificările instantanee nu sunt disponibile.",
    "No user supplied" : "Nu a fost furnizat niciun utilizator",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă administrativă de recuperare, altfel toate datele utilizatorilor vor fi pierdute",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalarea și actualizarea aplicațiilor prin intermediul App Store sau Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Partajare federalizată cloud",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilizează o versiune %1$sneupdatată (%2$s). Vă rugăm să updatați sistemul de operare sau actualizați caracteristicile %3$scare nu funcționează în mod fiabil.",
    "Invalid user" : "Utilizator invalid",
    "Your username is: %s" : "Utilizatorul tău este: %s",
    "Logged in user must be a subadmin" : "Utilizatorul logat trebuie să fie un subadmin",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Este în așteptare o sarcină de lucru în fundal care verifică dacă există certificate SSL importate de utilizator. Vă rugăm să reveniți mai târziu.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Sunt prezente unele certificate SSL importate de utilizator, care nu mai sunt utilizate cu Nextcloud 21. Acestea pot fi importate în linia de comandă prin intermediul comenzii \"occ security:certificates:import\". Căile lor în interiorul directorului de date sunt prezentate mai jos.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Au fost găsite UUID-uri nevalabile ale utilizatorilor sau grupurilor LDAP. Vă rugăm să revizuiți setările \"Override UUID detection\" din partea Expert a configurației LDAP și să utilizați \"occ ldap:update-uuid\" pentru a le actualiza.",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Autentificarea cu doi factori poate fi impusă pentru toți utilizatorii și pentru grupuri specifice. Dacă aceștia nu au configurat un furnizor cu doi factori, nu se vor putea conecta la sistem.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Error while deleting the token" : "Eroare de ștergere token",
    "Use the credentials below to configure your app or device." : "Utilizați acreditările de mai jos pentru a vă configura aplicația sau dispozitivul.",
    "For security reasons this password will only be shown once." : "Din motive de securitate, această parolă va fi afișată doar o singură dată.",
    "Copied!" : "S-a copiat!",
    "Copy" : "Copiază",
    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
    "Your email address" : "Adresa ta de email",
    "You do not have permissions to see the details of this user" : "Nu aveți permisiuni pentru a vedea detaliile acestui utilizator",
    "Add group" : "Adaugă grup",
    "Show user backend" : "Arată administrare utilizator",
    "Send email to new user" : "Trimite email către noul utilizator",
    "Not saved" : "Nu a fost salvat",
    "Twitter" : "Twitter",
    "Show to logged in users only" : "Afișează doar pentru utilizatorii autentificați",
    "SMTP Username" : "Nume utilizator SMTP",
    "Set default expiration date" : "Setează data implicită de expirare",
    "Allow username autocompletion in share dialog" : "Permite autocompletarea numelor în dialogul de partajare"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
